
Package API
===========

This is the "raw" API documentation for the ``rattail`` package.  It hopefully
contains all pertinent info regarding available functions, classes and their
attributes and method signatures etc.

.. toctree::
   :maxdepth: 1

   rattail
   rattail/app
   rattail/auth
   rattail/autocomplete/base
   rattail/autocomplete/customers
   rattail/batch/custorder
   rattail/batch/handheld
   rattail/batch/handlers
   rattail/batch/labels
   rattail/batch/pricing
   rattail/batch/product
   rattail/batch/purchase
   rattail/batch/vendorcatalog
   rattail/board
   rattail/bouncer/index
   rattail/cleanup
   rattail/clientele
   rattail/commands.base
   rattail/commands.batch
   rattail/commands.make_appdir
   rattail/commands.typer
   rattail/config
   rattail/core
   rattail/csvutil
   rattail/custorders
   rattail/datasync/index
   rattail/db/index
   rattail/employment
   rattail/enum
   rattail/excel
   rattail/exceptions
   rattail/features/index
   rattail/filemon/index
   rattail/filemon/actions
   rattail/filemon/config
   rattail/filemon/linux
   rattail/filemon/util
   rattail/filemon/win32
   rattail/files
   rattail/gpc
   rattail/importing/index
   rattail/importing/handlers
   rattail/importing/importers
   rattail/importing/model
   rattail/importing/postgresql
   rattail/importing/rattail
   rattail/importing/sqlalchemy
   rattail/reporting/index
   rattail/reporting/handlers
   rattail/labels
   rattail/logging
   rattail/mail
   rattail/membership
   rattail/people
   rattail/problems/index
   rattail/products
   rattail/progress
   rattail/projects/index
   rattail/tailbone
   rattail/time
   rattail/trainwreck/index
   rattail/upgrades
   rattail/util
   rattail/vendors.catalogs
   rattail/vendors.handler
   rattail/win32
